/**
* Title: 		 ThreadManager
* Description:	 Test class used to monitor the active threads
* Copyright:     Copyright (c) 2013
* Company:       Morpheus Quality Technologies
* Creation date: 06-12-2013
* Last modified: 06-12-2013
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.util ;

import adriani.boudoir.Boudoir;
import adriani.boudoir.logging.WSLogger;

/**
* A very simple class used only during development or debug to monitor the status of all the threads
* used by this project.
*/
public class ThreadManager {
	
	/** Reference to the top-level <code>Boudoir</code> instance.											*/
	public 		 			Boudoir 			boudoir ;

	/** Retrieving the logger instance to be used for this class (static).									*/
	protected 				WSLogger			logger ;

  	/** Beginning of each logging message printed on the STDOUT	.											*/
	protected 				String 				leadingName 	= "ThreadManager - " ;
	
	/**
	* Standard constructor, bounding this class to a single <code>Boudoir</code> instance.
	* 
	* @param boudoir the <code>Boudoir</code> instance "owning" this object.
    */
    public ThreadManager(Boudoir boudoir) {

    	this.boudoir 	= boudoir ;
    	this.logger 	= boudoir.getLogger().getLogger(ThreadManager.class) ;
    }	

 	/**
	* Print on the STDOUT the list of all active threads in the current <code>ThreadGroup</code>.
	*/
    public void printList() {

		StringBuffer message = getFormattedList() ;
		System.out.println(message.toString()) ;
	}

 	/**
	* Print in the LOG file the list of all active threads in the current <code>ThreadGroup</code>.
	*/
    public void logList() {

		StringBuffer message = getFormattedList() ;
		logger.logInfo(message.toString()) ;
	}

	/**
	* Returns the array of active threads in the current <code>ThreadGroup</code>.
	*
	* @return a <code>StringBuffer</code> object describing the printable thread list.
	*/
    public StringBuffer getFormattedList() {

		Thread[] list = getList() ;
		//Thread.currentThread().setName("Boudoir library") ;

		StringBuffer message = new StringBuffer("\nTHREAD LIST:\n") ;
		for (int i = 0 ;  i < list.length; i++) if (list[i] != null) {
			message.append(list[i].getName() + " [" + list[i].getId() +"] - ") ;
			message.append("Priority: " + list[i].getPriority() + " (" + list[i].getState() + ")\n") ;
		}
		return message ;
	}

	/**
	* Returns the array of active threads in the current <code>ThreadGroup</code>.
	*
	* @return the array of all the active threads.
	*/
    public Thread[] getList() {

		ThreadGroup group = Thread.currentThread().getThreadGroup() ;
		Thread[] list = new Thread[group.activeCount()] ;
		if (group != null) group.enumerate(list) ;
		return list ;
	}

} // End of class