/**
* Title: 		 SimpleAnalyzer
* Description:	 Custom implementation of the general <code>GeneralAnalyzer</code> class
* Copyright:     Copyright (c) 2013
* Company:       Morpheus Quality Technologies
* Creation date: 06-12-2013
* Last modified: 13-12-2013
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.test ;

import adriani.boudoir.* ;
import adriani.boudoir.app.GeneralAnalyzer ;


/**
* Implementation of the general <code>GeneralAnalyzer</code> abstract class for the specific
* web service.<br/><br/>
*
* To provide an example of implementation, here we added the management of the <strong>CUSTOMER</strong>
* related analysis: remove the corresponding code if not necessary.
* 
*/
public class SimpleAnalyzer extends GeneralAnalyzer {

  	/** Number of times the input data did not match any customer in the database.						*/
	protected 				int 		no_customer 		= 0 ;

	/**
	* Standard constructor, creating the <code>ArrayList</code> object used to store the result
	* of each call when the web service is deployed in a multi-threading environment (default).
	* 
	* @param boudoir the <code>Boudoir</code> instance "owning" this object 
	*/
	public SimpleAnalyzer(Boudoir boudoir) {

		super(boudoir) ;
		this.leadingName	= "SimpleAnalyzer - " ; 
	}
	
// ***********************************************************************************************************
// **********************************			ANALYSIS			******************************************
// ***********************************************************************************************************

	/**
	* Override the parent's method by adding a new specific measure to the general purposes analysis 
	* (already handled in the parent class). In this case we add analysis results regarding number of
	* times we failed searching a customer.
	*
	* @return a string buffer object containing the formatted results of the analysis
	*/
	@Override
	public StringBuffer getResults() {
		
		StringBuffer report = super.getResults() ;
		
//		int complete = calls - (no_db + macro_error + no_customer) ;
		
		report.append("\nCUSTOM ANALYSIS:\n\n") ;
		report.append("Calls interrupted because the customer was not found : " +	no_customer			+ "\n") ;
		
		return report ;
	}
	
	/**
	* Override the parent's method by adding a new specific measure to the general purposes analysis 
	* (already handled in the parent class). In this case we add analysis results regarding number of
	* times we failed searching a customer.
	*
	* @return a string buffer object containing the formatted results of the analysis
	*/
	// PLACEHOLDER: not necessary at the moment
	/*
	@Override
	public void endCall(int code) {
		
		// Incrementing custom counters, then forwarding action to parent
		switch(code) {
			case ErrorMessage.NO_CUSTOMER				: addNoCustomer() ;			break ;
		}
		super.endCall(code) ;
	}
	*/
	
// **************************************************************************************************************
// **********************************			MUTATORS		*************************************************
// **************************************************************************************************************

	/**
	* Mutator method.
	*/
	public void addNoCustomer() 			{		this.no_customer++ ;										}

// **************************************************************************************************************
// **********************************			ACCESSORS		*************************************************
// **************************************************************************************************************

	/**
	* Accessor method.
	*/
	public int getNoCustomer() 				{		return this.no_customer ;									}

} // End of class