/**
* Title: 		 CustomerDTO
* Description:	 Simple Value Object class wrapping data retrieved from the TEST_CUSTOMERS table 
* Copyright:     Copyright (c) 2013
* Company:       Morpheus Quality Technologies
* Creation date: 06-12-2013
* Last modified: 12-12-2013
* @author 		 Stefano Adriani
* @version		 1.0
*/

package adriani.boudoir.test.model ;

import java.io.Serializable ;

import adriani.boudoir.util.Utilities;

/**
* A simple DTO object storing data describing data retrieved from TEST_CUSTOMERS table.<br/>
* This class is NOT immutable since allows data modification via setter methods: this 
* allows to set data on this class as long as they become available (i.e. after subsequent
* calls to the DAO layer).
* 
*/
public class CustomerDTO implements Serializable  { 
	
	/**	Serial ID number used to avoid serialization/deserialization issues									*/
	private static final 			long 				serialVersionUID = -2634550908147016242L;

	/** Class field depicting the entity attribute bound to this model class								*/
	protected						StringBuffer		name ;
	/** Class field depicting the entity attribute bound to this model class								*/
	protected						StringBuffer		surname ;
	
  	/** Beginning of each logging message produced by this class.											*/
	protected static 				String 				leadingName 		= "CustomerDTO - " ;
	
	/**
	* Empty constructor.
	*/ 
	public CustomerDTO() { }
	
	/**
	* Standard constructor.
	* 
	* @param name
	* @param surname
	*/
	public CustomerDTO(StringBuffer 	name		,
						StringBuffer 	surname
	) {
		super() ;
		this.name					= name ;
		this.surname				= surname ;
	}
	
	/**
	* Array oriented constructor.
	* 
	* @param array StringBuffer array containing all this model fields 
	*/
	public CustomerDTO(StringBuffer[] array) {
		
		this(	
			array[ 0 ]	,
			array[ 1 ]
		) ;
	}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************
	
	/**
	* Setter method.
	*/
	public void setName(StringBuffer value) 						{	this.name = value ;					}
	
	/**
	* Setter method.
	*/
	public void setSurname(StringBuffer value) 						{	this.surname = value ;				}
	
// **********************************************************************************************************
// **********************************			GETTERS			*********************************************
// **********************************************************************************************************
	
	/**
	* Getter method.
	*/
	public StringBuffer getName() 									{	return this.name ;					}
	
	/**
	* Getter method.
	*/
	public StringBuffer getSurname() 								{	return this.surname ;				}
	
} // End of class