/**
* Title: 		 EntityTimesDTO
* Description:	 Simple Value Object class wrapping data retrieved from the TEST_ENTITY_TIMES table 
* Copyright:     Copyright (c) 2013
* Company:       Morpheus Quality Technologies
* Creation date: 06-12-2013
* Last modified: 12-12-2013
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.test.model ;

import java.io.Serializable ;

import adriani.boudoir.util.Utilities;

/**
* A simple DTO object storing data describing data retrieved from TEST_ENTITY_TIMES table.<br/>
* This class is NOT immutable since allows data modification via setter methods: this 
* allows to set data on this class as long as they become available (i.e. after subsequent
* calls to the DAO layer).
* 
*/
public class EntityTimeDTO implements Serializable  { 
	
	/**	Serial ID number used to avoid serialization/deserialization issues			*/
	private static final 			long 				serialVersionUID = -6246977161905166151L;

	/** Class field depicting the entity attribute bound to this model class		*/
	protected						StringBuffer		end_time ;
	
  	/** Beginning of each logging message produced by this class.											*/
	protected static 				String 				leadingName 		= "EntityTimesDTO - " ;
	
	/**
	* Empty constructor.
	*/ 
	public EntityTimeDTO() { }
	
	/**
	* Standard constructor.
	* 
	* @param end_time
	*/
	public EntityTimeDTO(StringBuffer end_time) {
		
		super() ;
		this.end_time				= end_time ;
	}
	
	/**
	* Array oriented constructor.
	* 
	* @param array StringBuffer array containing all this model fields 
	*/
	public EntityTimeDTO(StringBuffer[] array) {
		
		this(	
			array[ 0 ]
			// Example: for long array just list all entries, optionally converting them
			// using the Utilities methods.
			// , array[ 1 ]
		) ;
	}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************
	
	/**
	* Setter method.
	*/
	public void setEndTime(StringBuffer value) 						{	this.end_time = value ;			}
	
// **********************************************************************************************************
// **********************************			GETTERS			*********************************************
// **********************************************************************************************************
	
	/**
	* Getter method.
	*/
	public StringBuffer getEndTime() 								{	return this.end_time ;				}
	
	/**
	* Getter method (overloaded).
	*/
	public String getStringEndTime() {
		
		if (this.end_time != null)		return this.end_time.toString() ;	
		else							return null ;	
	}
	
	/**
	* Getter method (overloaded).
	*/
	public java.util.Date getDateEndTime() {
		
		return Utilities.valueOfDate( this.end_time ) ;
	}
	
} // End of class