/**
* Title: 		 ClientThread
* Description:	 
* Copyright:     Copyright (c) 2014
* Company:       Morpheus Quality Technologies
* Creation date: 10-01-2014
* Last modified: 10-01-2014
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.test.util ;

import adriani.boudoir.Boudoir ;
import adriani.boudoir.logging.WSLogger ;

import adriani.boudoir.test.SimpleLogic ;

/**
*
*
*/
public class ClientThread extends Thread {
	
	/** Reference to the top-level <code>Boudoir</code> instance.												*/
	public 		 				Boudoir 				boudoir ;
	
	/** Reference to the Simple Application to be tested.														*/
	public 		 				SimpleLogic				application ;
	
	/** String array containing input data for the application to be tested.									*/
	public 		 				StringBuffer[]			data ;

	/** Boolean flag depicting status on this thread.															*/
	protected 					boolean 				running 			= false ;	// Default value
	
	/** Retrieving the logger instance to be used for this class.												*/
	protected 		 			WSLogger		logger ;

  	/** Beginning of each logging message produced by this class												*/
	protected 		 			String 					leadingName ;
	
	/**
	* Standard constructor.
	*
	* @param boudoir the <code>Boudoir</code> used to invoke the Simple Application
	* @param sleepTime the sleep time for this thread, in seconds
	*/
	public ClientThread(Boudoir boudoir) {

		this.boudoir 	= boudoir ;
    	this.logger 	= boudoir.getLogger().getLogger(ClientThread.class) ;		

		// Setting a different name to each thread
		String name = "ClientThread:" + this.getId() ;
		this.setName(name) ;
		this.leadingName = name + " - ";
	}
	
	/**
	* Mutator method, setting target application and corresponding data.
	* 
	* @param simpleLogic
	* @param input
	*/
	public void setTarget(SimpleLogic simpleLogic, StringBuffer[] input) {
		
		this.application 	= simpleLogic ;
		this.data			= input ;
	}

	/**
	* This methods runs once, calling the Simple Application first method and setting such application to delay the
	* response for few seconds, in order to allow testing of the pool saturation.
	* 
	* @see SimpleClient#testLoadPool()
	*/
	public void run() {

		// Logging start information
		this.running = true ;		
		if (logger.isInfoEnabled()) logger.logInfo(leadingName + "Started") ;
		
		// Invoking target application
		application.getCustomerDummy(data) ;

		// We don't need to stop this thread, since we stop SimpleClient execution instead!
		// try 								{	sleep(sleepTime) ; 												}
		// catch (InterruptedException e)	{ 	logger.logSevere(leadingName + "Interrupted while sleeping") ; 	}
		
		// Ending execution
		if (logger.isInfoEnabled()) logger.logInfo(leadingName + "Exiting") ;
		this.running = false ;
	}
	
} // End of class