/**
* Title: 		 CustomerWrapper
* Description:	 Example of output wrapper returned by the <code>SimpleLogic</code> class
* Copyright:     Copyright (c) 2013-2014
* Company:       Morpheus Quality Technologies
* Creation date: 03-12-2013
* Last modified: 07-01-2014
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.test.wrappers ;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import adriani.boudoir.* ;

/**
* Example of output wrapper returned by the <code>SimpleLogic</code> class.
*/
public class CustomerWrapper extends Wrapper {
	
	/** Reference to the top-level <code>Boudoir</code> instance.											*/
	public		 			Boudoir 			boudoir ;

  	/** Wrapped output value.																				*/
	protected 				StringBuffer	 	name ;
  	/** Wrapped output value.																				*/
	protected 				StringBuffer	 	surname ;

	/** Default value for the field wrapped by this class.													*/
	public static final 	StringBuffer		DEFAULT_NAME 		= new StringBuffer("UNKNOWN") ; 
	/** Default value for the field wrapped by this class.													*/
	public static final 	StringBuffer		DEFAULT_SURNAME 	= new StringBuffer("UNKNOWN") ; 
	
	/** Static regex pattern used to check if the customer number begins with "23".							*/
	public static final 	Pattern 			DIGIT				= Pattern.compile("\\d+", Pattern.CASE_INSENSITIVE) ;
	
  	/** Beginning of each logging message produced by this class.											*/
	protected static		String 		 		leadingName 		= "CustomerWrapper - " ;
	
	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see #setDefaults()
	*/
	public CustomerWrapper() {
		
		this.setDefaults() ;
	}

	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see #setDefaults()
	*/
	public CustomerWrapper(Boudoir boudoir) {

		this() ;
		this.boudoir = boudoir ;
		//System.out.println(leadingName + "Created new instance") ;
	}

// **********************************************************************************************************
// **********************************		ADBBEAN MANAGEMENT		*****************************************
// **********************************************************************************************************

	/**
	* Example of validation for the output object. If data contained within this wrappers requires some 
	* validation, the application business logic could need to invoke this method before returning it.
	* This is just an example of simple validation, assuming that wrapped data are name and surname: 
	* in such scenario we define "valid" this object if both name and surname do not contain any 
	* digit.
	* 
	* @return <code>true</code> if wrapped data are valid
	*/
	public boolean validate() throws Exception {

		// 1. Preparing variables
		String 		msg 	= null ;
		System.out.println(leadingName + "Validating fields: " + name + " - " + surname) ;

		// 2. Performing trivial validation
		Matcher matcher ;
		matcher = DIGIT.matcher(name) ;
		if (matcher.matches()) {
			msg 	= "Wrong name" ;
			name 	= DEFAULT_NAME ;
		}
		matcher = DIGIT.matcher(surname) ;
		if (matcher.matches()) {
			msg 	= "Wrong surname" ;
			surname = DEFAULT_SURNAME ;
		}
		
		// 3. Handling errors
		if (msg == null) {
			if (boudoir.getConfiguration().VERBOSE) System.out.println(leadingName + "Wrapped a valid single record") ;
		} else {
			if (boudoir.getConfiguration().VERBOSE) System.out.println(leadingName + "Invalid single wrapper, using defaults") ;
			throw new Exception(msg) ;
		}

		// 4. Returning validation result
		return (msg == null) ;
	}

	/**
	* Load all the STATIC default values (defined in this class) into the corresponding class attributes.
	* This method is called by the constructor to ensure that we "empty wrapper" contains always some
	* good default values matching the WSDL constrains. This is necessary since in the WSDL we didnt'
	* define these fields as <em>minOccurs='0'</em>.
	*
	* @see #CustomerWrapper()
	*/
	public void setDefaults() {

		setName		( DEFAULT_NAME 		) ;
		setSurname	( DEFAULT_SURNAME 	) ;
		//System.out.println(leadingName + "Set defaults values") ;
	}

// **********************************************************************************************************
// **********************************			ACCESSORS		*********************************************
// **********************************************************************************************************

	/**
	* Accessor method.
	*/
	public StringBuffer getName()					{		return this.name ;								}

	/**
	* Accessor method.
	*/
	public StringBuffer getSurname()				{		return this.surname ;							}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************

	/**
	* Mutator method.
	*/
	public void setName(StringBuffer value)			{		this.name = value ;								}

	/**
	* Mutator method.
	*/
	public void setSurname(StringBuffer value)		{		this.surname = value ;							}

} // End of class