/**
* Title: 		 EntityTimeWrapper
* Description:	 Example of output wrapper returned by the <code>SimpleLogic</code> class
* Copyright:     Copyright (c) 2014
* Company:       Morpheus Quality Technologies
* Creation date: 07-01-2014
* Last modified: 08-01-2014
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package adriani.boudoir.test.wrappers ;

import adriani.boudoir.* ;
import adriani.boudoir.util.Utilities ;

/**
* Example of output wrapper returned by the <code>SimpleLogic</code> class.<br/><br/>
* 
* <strong>Remark:</strong> this wrapper performs some redundant job, since the DTO retrieves the database 
* date as a StringBuffer object, and here we convert it back into a date. This could be avoided with
* a better architecture: we chosen to convert back to the date format just to show an example of usage
* of the Boudoir date-time conversion utilities. 
*/
public class EntityTimeWrapper extends Wrapper {
	
	/** Reference to the top-level <code>Boudoir</code> instance.											*/
	public		 			Boudoir 			boudoir ;

  	/** Wrapped output value.																				*/
	protected 				java.util.Date		time ;

	/** Default value for the field wrapped by this class.													*/
	public static final 	java.util.Date	DEFAULT_TIME 		= new java.util.Date(0) ; 
	
  	/** Beginning of each logging message produced by this class.											*/
	protected static		String 		 		leadingName 		= "EntityTimeWrapper - " ;
	
	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see #setDefaults()
	*/
	public EntityTimeWrapper() {
		
		this.setDefaults() ;
	}

	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see #setDefaults()
	*/
	public EntityTimeWrapper(Boudoir boudoir) {

		this() ;
		this.boudoir = boudoir ;
		//System.out.println(leadingName + "Created new instance") ;
	}

// **********************************************************************************************************
// **********************************		ADBBEAN MANAGEMENT		*****************************************
// **********************************************************************************************************

	/**
	* Example of validation for the output object. If data contained within this wrappers requires some 
	* validation, the application business logic could need to invoke this method before returning it.
	* This is just an example of simple validation, assuming that wrapped data are name and surname: 
	* in such scenario we define "valid" this object if both name and surname do not contain any 
	* digit.
	* 
	* @return <code>true</code> if wrapped data are valid
	*/
	public boolean validate() throws Exception {

		// 1. Preparing variables
		String 		msg 	= null ;
		System.out.println(leadingName + "Validating field: " + time) ;
		
		// No validation here (this is just a remind-placeholder)

		// 3. Returning validation result
		return (msg == null) ;
	}

	/**
	* Load all the STATIC default values (defined in this class) into the corresponding class attributes.
	* This method is called by the constructor to ensure that we "empty wrapper" contains always some
	* good default values matching the WSDL constrains. This is necessary since in the WSDL we didnt'
	* define these fields as <em>minOccurs='0'</em>.
	*
	* @see #CustomerWrapper()
	*/
	public void setDefaults() {

		setTime		( DEFAULT_TIME 		) ;
		//System.out.println(leadingName + "Set defaults values") ;
	}

// **********************************************************************************************************
// **********************************			ACCESSORS		*********************************************
// **********************************************************************************************************

	/**
	* Accessor method.
	*/
	public java.util.Date getTime()					{		return this.time ;								}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************

	/**
	* Mutator method.
	*/
	public void setTime(java.util.Date value)		{		this.time = value ;								}
	
	/**
	* Mutator method.
	*/
	public void setTime(StringBuffer value) {	
		
		java.util.Date date = Utilities.valueOfDate(value) ;
		
		// Keep for testing or debug: convert string date to a SQL date
		// java.util.Date date = Utilities.valueOfSQLDate(value) ;
		
		this.time = date ;
	}

} // End of class