--  ------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO execution of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
--  ------------------------------------------------------------------------------------------------------------

-- ------------------------------------------------------------------------------------------------------------
-- 1. CREATING A VERY SIMPLE TABLE, WITHOUT ANY CONSTRAINT
-- Example: this table could store execution times of detailed code blocks, referred as "entities"
-- An entity could be: a single http GET request, a single Ajax call, a single SQL query etc.
-- ------------------------------------------------------------------------------------------------------------

CREATE TABLE TEST_ENTITY_TIMES 
(
ID_ENTITY INT(11) NOT NULL, 
LABEL VARCHAR(500) NOT NULL, 
START_TIME DATETIME, 
END_TIME DATETIME 
) ;

-- 1.1 Creating the index for this table
-- Remark: MySQL does not support function-based index --> we create a plain index
CREATE INDEX ENTITY_TIMES_INDEX ON TEST_ENTITY_TIMES(ID_ENTITY) ;

-- ------------------------------------------------------------------------------------------------------------
-- 2. CREATING ANOTHER VERY SIMPLE TABLE, WITH A PRIMARY KEY
-- ------------------------------------------------------------------------------------------------------------

CREATE TABLE TEST_CUSTOMERS (
  CUSTOMER_ID INT(11) NOT NULL PRIMARY KEY,
  NAME VARCHAR(20), 
  SURNAME VARCHAR(20), 
  COMPANY VARCHAR(30), 
  ADDRESS VARCHAR(30), 
  TOWN VARCHAR(20), 
  COUNTRY VARCHAR(20), 
  TELEPHONE VARCHAR(20)
) ;

-- ------------------------------------------------------------------------------------------------------------
-- 3. SAMPLE DATA FOR THE TEST_ENTITY_TIMES TABLE
-- ------------------------------------------------------------------------------------------------------------

-- REMARK: these lines are just an EXAMPLE: you need to adjust the date format with respect of your client's locale

INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (1 , 'A dummy http get request', '2012-04-10 11:00:00.0', '2012-04-10 11:00:01.0') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (2 , 'A dummy http ajax request', '2012-04-10 12:00:00.0', '2012-04-10 12:00:02.0') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (3 , 'A dummy SQL query', '2012-04-10 13:00:00', '2012-04-10 13:00:03') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (4 , 'A general entity' , '2012-04-10 13:01:00', '2012-04-10 13:01:03') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (5 , 'Benchmark_query_1', '2012-04-10 13:02:00', '2012-04-10 13:02:04') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (6 , 'Benchmark_query_1', '2012-04-10 13:03:00', '2012-04-10 13:03:02') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (7 , 'Benchmark_query_1', '2012-04-10 13:04:00', '2012-04-10 13:04:02') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (8 , 'Benchmark_query_1', '2012-04-10 13:05:00', '2012-04-10 13:05:05') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (9 , 'Benchmark_query_1', '2012-04-10 13:06:00', '2012-04-10 13:06:01') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (10, 'Benchmark_query_1', '2012-04-10 13:07:00', '2012-04-10 13:07:02') ;

-- ------------------------------------------------------------------------------------------------------------
-- 4. SAMPLE DATA FOR THE TEST_CUSTOMERS TABLE
-- ------------------------------------------------------------------------------------------------------------

INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (1, 'Stefano', 'Adriani', 'Italy', '0498978842') ;
INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (2, 'Steve'  , 'Goonie' , 'United Kingdom','010202404') ;
INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (3, 'Jousha' , 'Tree'   , 'Ireland', '0431999536') ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: CHECK DATA (just to verify the create procedure)
--------------------------------------------------------------------------------------------------------------
-- Check data entry
SELECT * FROM TEST_CUSTOMERS ;
SELECT * FROM TEST_ENTITY_TIMES ;

DROP TABLE TEST_CUSTOMERS ;
DROP TABLE TEST_ENTITY_TIMES ;

TRUNCATE TABLE TEST_CUSTOMERS ;
TRUNCATE TABLE TEST_ENTITY_TIMES ;
 */