-- ---------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO Function call of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
-- ---------------------------------------------------------------------------------------------------

DROP FUNCTION IF EXISTS TEST_GET_ENTITY_TIME ;

-- DELIMITER definition: within function definition we "disable" the character ";" from being the delimiter
-- REMARK: to not write any invisible character after '$$', otherwise that char will be part of the delimiter!
DELIMITER $$

CREATE FUNCTION TEST_GET_ENTITY_TIME(entity_label VARCHAR(500), entidy_id INT)
RETURNS INT READS SQL DATA
-- ---------------------------------------------------------------------------------------------------
-- FUNCTION            :   TEST_GET_ENTITY_TIME
-- LAST MODIFIED       :   10/09/2013
-- AUTHOR              :   S. ADRIANI
-- DESCRIPTION         :   Return the elapsed time for the input entity, matching label OR id.
--                     :   If both input parameters are given, the record must match both parameter.
--                     :   However it is possibile to pass one Of them as a NULL value

-- INPUT PARAMETERS
-- entity_label        :   The label of the entity, e.g. "Benchmark_query_1"
-- entidy_id           :   The ID of the entity (an integer number)

-- OUTPUT PARAMETERS
-- range_1             :   The elapsed time for the entity, i.e. END_TIME - START_TIME

-- REMARK              :   The result of this function could be obtained by a simple "old plain SQL query":
--                     :   here we used a function just to show some basic PL/SQL features
-- ---------------------------------------------------------------------------------------------------

BEGIN

-- Inner variables
DECLARE  range_1 INT ;

  -- 1. If we have both parameters we try a double match
  IF (entity_label IS NOT NULL) AND (entidy_id IS NOT NULL) THEN

   SELECT (
    (extract(hour from END_TIME) - extract(hour from START_TIME))*3600+
    (extract(minute from END_TIME) - extract(minute from START_TIME))*60+
     extract(second from END_TIME) - extract(second from START_TIME)
	) SEC
    INTO range_1
    FROM TEST_ENTITY_TIMES
    WHERE ID_ENTITY = entidy_id
    AND LABEL = entity_label ;

  -- 2. Else we try a single match
  ELSE

	SELECT (
    (extract(hour from END_TIME) - extract(hour from START_TIME))*3600+
    (extract(minute from END_TIME) - extract(minute from START_TIME))*60+
     extract(second from END_TIME) - extract(second from START_TIME)
	) SEC
    INTO range_1
    FROM TEST_ENTITY_TIMES
    WHERE ID_ENTITY = entidy_id
    OR LABEL = entity_label ;

  END IF ;

  -- 3. Returning result
  RETURN range_1 ;

END $$

-- Restoring default delimiter (i.e. the ";" character)
DELIMITER ;

/*
-----------------------------------------------------------------------------------------------------
-- OPTIONAL: SQL STATEMENT FOR TESTING/DEBUG ON A SQL CLIENT
-----------------------------------------------------------------------------------------------------

-- Below are listed some alternative ways to verify creation of the TEST_GET_ENTITY_TIME function:

-- 1. Browse the content of the ROUTINES table using phpMyAdmin, by executing:
USE information_schema;

-- 2. Browse the content of the ROUTINES table by directly accessing to it:
SELECT * FROM information_schema.routines WHERE routine_schema = 'prova';

-- 3. Invoke the function to test it's working
SELECT TEST_GET_ENTITY_TIME(null,1) from dual;

--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: MAINTENANCE QUERIES
--------------------------------------------------------------------------------------------------------------

DROP FUNCTION TEST_GET_ENTITY_TIME ;

*/