-- ---------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO Procedure call of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
-- ---------------------------------------------------------------------------------------------------

DROP PROCEDURE IF EXISTS TEST_VERIFY_ENTITY_ID ;

-- DELIMITER definition: within procedure definition we "disable" the character ";" from being the delimiter
-- REMARK: to not write any invisible character after '$$', otherwise that char will be part of the delimiter!
DELIMITER $$

CREATE PROCEDURE TEST_VERIFY_ENTITY_ID(IN entity_id INT, INOUT entity_label VARCHAR(500))
-- ------------------------------------------------------------------------------------------------------------
-- PROCEDURE           :   TEST_VERIFY_ENTITY_ID
-- LAST MODIFIED       :   10/09/2013
-- AUTHOR              :   S. ADRIANI
-- DESCRIPTION         :   Return the label for the input entity ID (for this usage entity_label should be '0'
--                     :   or NULL. The procedure allows to force the result passing as input a not null
--                     :   label: in such case the input label is returned istead of the right one.

-- INPUT PARAMETERS
-- entity_id           :   The ID of the entity (an integer number)
-- entity_label        :   The label of the entity, e.g. "Benchmark_query_1"

-- OUTPUT PARAMETERS   :   
-- entity_label        :   the entity label mathcing the input entity_id (if entity_label is null) or the
--                         input entity_label itself (if not null)

-- REMARK              :   The result of this procedure could be obtained by a simple "old plain SQL query":
--                     :   here we used a procedure just to show some basic PL/SQL features
-- ------------------------------------------------------------------------------------------------------------

BEGIN

  IF ( (entity_label = '0') OR (entity_label IS NULL) ) THEN
    
    BEGIN
    
      SELECT tet.label INTO entity_label FROM test_entity_times tet
      WHERE tet.id_entity = entity_id ;
          
    END ;
	
  END IF ;

END $$

-- Restoring default delimiter (i.e. the ";" character)
DELIMITER ;

/*
-----------------------------------------------------------------------------------------------------
-- OPTIONAL: SQL STATEMENT FOR TESTING/DEBUG ON A SQL CLIENT
-----------------------------------------------------------------------------------------------------

-- Below are listed some alternative ways to verify creation of the TEST_VERIFY_ENTITY_ID procedure:

-- 1. Browse the content of the ROUTINES table using phpMyAdmin, by executing:
USE information_schema;

-- 2. Browse the content of the ROUTINES table by directly accessing to it:
SELECT * FROM information_schema.routines WHERE routine_schema = 'prova';

-- 3. Invoke the procedure to test it's working
SET @label = null ;
call TEST_VERIFY_ENTITY_ID(1, @label) ;
SELECT @label ;

--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: MAINTENANCE QUERIES
--------------------------------------------------------------------------------------------------------------

DROP PROCEDURE TEST_VERIFY_ENTITY_ID ;

*/