--------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO execution of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
--------------------------------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------------------------------
-- 1. CREATING A VERY SIMPLE TABLE, WITHOUT ANY CONSTRAINT
-- Example: this table could store execution times of detailed code blocks, referred as "entities"
-- An entity could be: a single http GET request, a single Ajax call, a single SQL query etc.
--------------------------------------------------------------------------------------------------------------

CREATE TABLE TEST_ENTITY_TIMES
(
ID_ENTITY INTEGER NOT NULL, 
LABEL VARCHAR(500) NOT NULL, 
START_TIME TIMESTAMP (4), 
END_TIME TIMESTAMP (4)
) ;
-- 1.1 Creating the index for this table
CREATE INDEX ENTITY_TIMES_INDEX ON TEST_ENTITY_TIMES (DATE_TRUNC('day', START_TIME)) ;

--------------------------------------------------------------------------------------------------------------
-- 2. CREATING ANOTHER VERY SIMPLE TABLE, WITH A PRIMARY KEY
--------------------------------------------------------------------------------------------------------------

CREATE TABLE TEST_CUSTOMERS (
  CUSTOMER_ID INTEGER NOT NULL, 
  NAME VARCHAR(20), 
  SURNAME VARCHAR(20), 
  COMPANY VARCHAR(30), 
  ADDRESS VARCHAR(30), 
  TOWN VARCHAR(20), 
  COUNTRY VARCHAR(20), 
  TELEPHONE VARCHAR(20), 
  CONSTRAINT CUSTOMERS_TBL_PK PRIMARY KEY (CUSTOMER_ID)
) ;

--------------------------------------------------------------------------------------------------------------
-- 3. SAMPLE DATA FOR THE TEST_ENTITY_TIMES TABLE
--------------------------------------------------------------------------------------------------------------

-- REMARK: these lines are just an EXAMPLE: you need to adjust the date format with respect of your client's locale

INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (1 , 'A dummy http get request', '10-APR-2012 11:00:00', '10-APR-2012 11:00:01') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (2 , 'A dummy http ajax request', '10-APR-2012 12:00:00', '10-APR-2012 12:00:02') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (3 , 'A dummy SQL query', '10-APR-2012 13:00:00', '10-APR-2012 13:00:03') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (4 , 'A general entity' , '10-APR-2012 13:01:00', '10-APR-2012 13:01:03') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (5 , 'Benchmark_query_1', '10-APR-2012 13:02:00', '10-APR-2012 13:02:04') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (6 , 'Benchmark_query_1', '10-APR-2012 13:03:00', '10-APR-2012 13:03:02') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (7 , 'Benchmark_query_1', '10-APR-2012 13:04:00', '10-APR-2012 13:04:02') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (8 , 'Benchmark_query_1', '10-APR-2012 13:05:00', '10-APR-2012 13:05:05') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (9 , 'Benchmark_query_1', '10-APR-2012 13:06:00', '10-APR-2012 13:06:01') ;
INSERT INTO TEST_ENTITY_TIMES (ID_ENTITY, LABEL, START_TIME, END_TIME) VALUES (10, 'Benchmark_query_1', '10-APR-2012 13:07:00', '10-APR-2012 13:07:02') ;

--------------------------------------------------------------------------------------------------------------
-- 4. SAMPLE DATA FOR THE TEST_CUSTOMERS TABLE
--------------------------------------------------------------------------------------------------------------

INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (1, 'Stefano', 'Adriani', 'Italy', '0498978842') ;
INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (2, 'Steve'  , 'Goonie' , 'United Kingdom','010202404') ;
INSERT INTO TEST_CUSTOMERS (CUSTOMER_ID, NAME, SURNAME, COUNTRY, TELEPHONE) VALUES (3, 'Jousha' , 'Tree'   , 'Ireland', '0431999536') ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: maintenance queries (useful to check/cleanup the tables above)
--------------------------------------------------------------------------------------------------------------
-- Check data entry
SELECT * FROM TEST_CUSTOMERS ;
SELECT * FROM TEST_ENTITY_TIMES ;

-- Delete all data
DELETE FROM TEST_CUSTOMERS ;
DELETE FROM TEST_ENTITY_TIMES ;

-- Drop tables
DROP TABLE TEST_CUSTOMERS ;
DROP TABLE TEST_ENTITY_TIMES ;
 */