--------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO Function call of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
--------------------------------------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION TEST_GET_ENTITY_TIME(entity_label IN VARCHAR, entidy_id IN INTEGER)
RETURNS INTEGER AS $BODY$
--------------------------------------------------------------------------------------------------------------
-- FUNCTION            :   TEST_GET_ENTITY_TIME
-- LAST MODIFIED       :   02/09/2013
-- AUTHOR              :   S. ADRIANI
-- DESCRIPTION         :   Return the elapsed time for the input entity, matching label OR id.
--                     :   If both input parameters are given, the record must match both parameter.
--                     :   However it is possibile to pass one Of them as a NULL value

-- INPUT PARAMETERS
-- entity_label        :   The label of the entity, e.g. "Benchmark_query_1"
-- entidy_id           :   The ID of the entity (an integer number)

-- OUTPUT PARAMETERS
-- range_1             :   The elapsed time for the entity, i.e. END_TIME - START_TIME

-- REMARK              :   The result of this function could be obtained by a simple "old plain SQL query":
--                     :   here we used a function just to show some basic PL/SQL features
--------------------------------------------------------------------------------------------------------------

DECLARE

  -- Inner variable
  range_1           INTEGER ;

BEGIN

  -- 1. If we have both parameters we try a double match
  IF (entity_label IS NOT NULL) AND (entidy_id IS NOT NULL) THEN

   SELECT (
    (extract(hour from END_TIME) - extract(hour from START_TIME))*3600+
    (extract(minute from END_TIME) - extract(minute from START_TIME))*60+
     extract(second from END_TIME) - extract(second from START_TIME)
	) SEC
    INTO range_1
    FROM TEST_ENTITY_TIMES
    WHERE ID_ENTITY = entidy_id
    AND LABEL = entity_label ;

  -- 2. Else we try a single match
  ELSE

	SELECT (
    (extract(hour from END_TIME) - extract(hour from START_TIME))*3600+
    (extract(minute from END_TIME) - extract(minute from START_TIME))*60+
     extract(second from END_TIME) - extract(second from START_TIME)
	) SEC
    INTO range_1
    FROM TEST_ENTITY_TIMES
    WHERE ID_ENTITY = entidy_id
    OR LABEL = entity_label ;

  END IF ;

  -- 3. Returning result
  RETURN range_1 ;

END ;
$BODY$
LANGUAGE plpgsql ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: SQL STATEMENT FOR TESTING/DEBUG ON A SQL CLIENT
--------------------------------------------------------------------------------------------------------------

SELECT TEST_GET_ENTITY_TIME('A general entity', 4) ;
SELECT TEST_GET_ENTITY_TIME('A general entity', NULL) ;
SELECT TEST_GET_ENTITY_TIME(null, 4) ;

--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: MAINTENANCE QUERIES
--------------------------------------------------------------------------------------------------------------

DROP FUNCTION TEST_GET_ENTITY_TIME(VARCHAR, INTEGER) ;

*/