--------------------------------------------------------------------------------------------------------------
-- TITLE           :   SQL components used to test DAO Procedure call of the "Boudoir Library" project.
-- CREATION DATE   :   15/11/2013
-- LAST MODIFIED   :   15/11/2013
-- AUTHOR          :   S. ADRIANI
-- VERSION         :   1.0
-- TO DO           :   Nothing
--------------------------------------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION TEST_VERIFY_ENTITY_ID(entity_id IN INTEGER, entity_label IN OUT VARCHAR)
AS $BODY$
--------------------------------------------------------------------------------------------------------------
-- FUNCTION            :   TEST_VERIFY_ENTITY_ID
-- LAST MODIFIED       :   03/09/2013
-- AUTHOR              :   S. ADRIANI
-- DESCRIPTION         :   Return the label for the input entity ID (for this usage entity_label should be '0'
--                     :   or NULL. The procedure allows to force the result passing as input a not null
--                     :   label: in such case the input label is returned istead of the right one.

-- INPUT PARAMETERS
-- entity_id           :   The ID of the entity (an integer number)
-- entity_label        :   The label of the entity, e.g. "Benchmark_query_1"

-- OUTPUT PARAMETERS   :   
-- entity_label        :   the entity label mathcing the input entity_id (if entity_label is null) or the
--                         input entity_label itself (if not null)

-- REMARK              :   The result of this procedure could be obtained by a simple "old plain SQL query":
--                     :   here we used a procedure just to show some basic PL/SQL features
--------------------------------------------------------------------------------------------------------------

BEGIN
    
  IF ( (entity_label = '0') OR (entity_label IS NULL) ) THEN
    
    BEGIN
    
      SELECT tet.label INTO entity_label FROM test_entity_times tet
      WHERE tet.id_entity = entity_id ;
          
    END ;
	
  END IF ;
  
END ;
$BODY$
LANGUAGE plpgsql ;

/*
--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: SQL STATEMENT FOR TESTING/DEBUG ON A SQL CLIENT
--------------------------------------------------------------------------------------------------------------

SELECT TEST_VERIFY_ENTITY_ID(4, null) ;
SELECT TEST_VERIFY_ENTITY_ID(0, 'A general entity') ;
SELECT TEST_VERIFY_ENTITY_ID(4, 'A general entity') ;

--------------------------------------------------------------------------------------------------------------
-- OPTIONAL: MAINTENANCE QUERIES
--------------------------------------------------------------------------------------------------------------

DROP FUNCTION TEST_VERIFY_ENTITY_ID(INTEGER, VARCHAR) ;

*/